@@ -984,6 +984,20 @@ script_exec_new (const char  *uri,
     {
       char *tmpl;
       const char *sandbox_dir;
+      g_autofree char *resolved_infile = NULL;
+
+      /* Make sure any symlinks in the path are resolved, because the resolved
+       * path is what's exposed by Flatpak into the sandbox */
+      resolved_infile = realpath (exec->infile, NULL);
+      if (!resolved_infile)
+        {
+          g_set_error (error, G_IO_ERROR, g_io_error_from_errno (errno),
+                       "Failed to resolve '%s': '%s'", exec->infile, g_strerror (errno));
+          goto bail;
+        }
+
+      g_free (exec->infile);
+      exec->infile = g_steal_pointer (&resolved_infile);
 
       sandbox_dir = g_getenv ("FLATPAK_SANDBOX_DIR");
       if (!sandbox_dir || *sandbox_dir != '/')
@@ -1080,6 +1094,11 @@ print_script_debug (GStrv expanded_script)
   g_string_free (out, TRUE);
 }
 
+/* Compatibility shim for older versions of GLib */
+#if !GLIB_CHECK_VERSION (2, 70, 0)
+#define g_spawn_check_wait_status(status,error) g_spawn_check_exit_status (status, error)
+#endif
+
 GBytes *
 gnome_desktop_thumbnail_script_exec (const char  *cmd,
 				     int          size,
@@ -1107,7 +1126,7 @@ gnome_desktop_thumbnail_script_exec (const char  *cmd,
   ret = g_spawn_sync (NULL, expanded_script, NULL, G_SPAWN_SEARCH_PATH,
 		      child_setup, exec->fd_array, NULL, &error_out,
 		      &exit_status, error);
-  if (ret && g_spawn_check_exit_status (exit_status, error))
+  if (ret && g_spawn_check_wait_status (exit_status, error))
     {
       char *contents;
       gsize length;
